@@ -41,24 +41,24 @@ class Syringe:
 
     async def get_diameter(self) -> Quantity:
         """Get syringe diameter configured in the pump."""
-        output = await self._pump._write("diameter")
+        output = await self._pump._write("diameter", error_state_ok=True)
         diameter, _ = extract_quantity(output.message[0])
         return diameter
 
     async def set_diameter(self, diameter: float):
         """Set syringe diameter in mm."""
-        return await self._pump._write(f"diameter {diameter:.4}")
+        return await self._pump._write(f"diameter {diameter:.4}", error_state_ok=True)
 
     async def get_volume(self) -> Quantity:
         """Get syringe volume configured in the pump."""
-        output = await self._pump._write("svolume")
+        output = await self._pump._write("svolume", error_state_ok=True)
         volume, _ = extract_quantity(output.message[0])
         return volume
 
     async def set_volume(self, volume: Quantity):
         """Set syringe volume."""
         _check_volume(volume)
-        await self._pump._write(f"svolume {volume:.4}")
+        await self._pump._write(f"svolume {volume:.4}", error_state_ok=True)
 
     async def set_manufacturer(
         self, manufacturer: Manufacturer, volume: Quantity | None = None
@@ -68,13 +68,17 @@ class Syringe:
             if volume is not None:
                 _check_volume(volume)
                 response = await self._pump._write(
-                    f"syrmanu {manufacturer.name} {volume:.4} "
+                    f"syrmanu {manufacturer.name} {volume:.4}", error_state_ok=True
                 )
             else:
-                response = await self._pump._write(f"syrmanu {manufacturer.name}")
+                response = await self._pump._write(
+                    f"syrmanu {manufacturer.name}", error_state_ok=True
+                )
         except PumpCommandError as e:
             if "Unknown syringe" in e.response.message[1]:
-                options = await self._pump._write(f"syrmanu {manufacturer.name} ?")
+                options = await self._pump._write(
+                    f"syrmanu {manufacturer.name} ?", error_state_ok=True
+                )
                 raise ValueError(
                     f"Unknown syringe. Valid volumes are: \n{options.raw_text}"
                 ) from e
@@ -83,7 +87,7 @@ class Syringe:
 
     async def get_manufacturer(self):
         """Get syringe manufacturer configured in the pump."""
-        output = await self._pump._write("syrmanu")
+        output = await self._pump._write("syrmanu", error_state_ok=True)
         print(output.message)
         manu, volume, diam = output.message[0].split(",")
         return manu, Quantity(volume), Quantity(diam)
